"""
echo

Print all arguments to standard output, separated by spaces.
"""

def main(*args):
    print(' '.join(args))
    return 0
